summaryrefslogtreecommitdiffstats
path: root/kmail/kmfoldermaildir.h
diff options
context:
space:
mode:
Diffstat (limited to 'kmail/kmfoldermaildir.h')
-rw-r--r--kmail/kmfoldermaildir.h21
1 files changed, 11 insertions, 10 deletions
diff --git a/kmail/kmfoldermaildir.h b/kmail/kmfoldermaildir.h
index d8be0139..83cb0b68 100644
--- a/kmail/kmfoldermaildir.h
+++ b/kmail/kmfoldermaildir.h
@@ -24,10 +24,11 @@ using KMail::AttachmentStrategy;
class KMFolderMaildir : public KMFolderIndex
{
Q_OBJECT
+ TQ_OBJECT
friend class ::KMail::MaildirJob;
public:
- /** Usually a parent is given. But in some cases there is no
- fitting parent object available. Then the name of the folder
+ /** Usually a tqparent is given. But in some cases there is no
+ fitting tqparent object available. Then the name of the folder
is used as the absolute path to the folder file. */
KMFolderMaildir(KMFolder* folder, const char* name=0);
virtual ~KMFolderMaildir();
@@ -55,10 +56,10 @@ public:
virtual void removeMsg(TQPtrList<KMMessage> msgList, bool imapQuiet = FALSE)
{ return KMFolderIndex::removeMsg(msgList, imapQuiet); }
- // Called by KMMsgBase::seStatus when status of a message has changed
+ // Called by KMMsgBase::setqStatus when status of a message has changed
// required to keep the number unread messages variable current.
- virtual void msgStatusChanged( const KMMsgStatus oldStatus,
- const KMMsgStatus newStatus,
+ virtual void msgStatusChanged( const KMMsgtqStatus oldtqStatus,
+ const KMMsgtqStatus newtqStatus,
int idx);
/** Open folder for access.
@@ -86,7 +87,7 @@ public:
static int createMaildirFolders( const TQString & folderPath );
static TQString constructValidFileName( const TQString & filename = TQString(),
- KMMsgStatus status = KMMsgStatusNew );
+ KMMsgtqStatus status = KMMsgStatusNew );
static bool removeFile( const TQString & folderPath,
const TQString & filename );
@@ -147,9 +148,9 @@ private slots:
void slotDirSizeJobResult( KIO::Job* job );
private:
- void readFileHeaderIntern(const TQString& dir, const TQString& file, KMMsgStatus status);
+ void readFileHeaderIntern(const TQString& dir, const TQString& file, KMMsgtqStatus status);
TQString moveInternal(const TQString& oldLoc, const TQString& newLoc, KMMsgInfo* mi);
- TQString moveInternal(const TQString& oldLoc, const TQString& newLoc, TQString& aFileName, KMMsgStatus status);
+ TQString moveInternal(const TQString& oldLoc, const TQString& newLoc, TQString& aFileName, KMMsgtqStatus status);
bool removeFile(const TQString& filename);
/** Tests whether the contents of this folder is newer than the index.
@@ -157,9 +158,9 @@ private:
Returns IndexMissing if there is no index.
Returns IndexOk if the index is not older than the contents.
*/
- virtual IndexStatus indexStatus();
+ virtual IndextqStatus indextqStatus();
- typedef QPair<TQGuardedPtr<const KMFolderMaildir>,KFileItemList> DirSizeJobQueueEntry;
+ typedef TQPair<TQGuardedPtr<const KMFolderMaildir>,KFileItemList> DirSizeJobQueueEntry;
static TQValueList<DirSizeJobQueueEntry> s_DirSizeJobQueue;
TQStrList mIdxToFileList;